# -*- coding: utf-8 -*- #
# Copyright 2024 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The command group for Audit Manager CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.DefaultUniverseOnly
@base.ReleaseTracks(base.ReleaseTrack.GA)
class AuditManager(base.Group):
  """Enroll resources, audit workloads and generate reports."""

  category = base.SECURITY_CATEGORY

  def Filter(self, context, args):
    del context, args
    # Don't ever take this off. Use gcloud quota for projects operations so
    # you can create a project before you have a project.
    base.DisableUserProjectQuota()


@base.DefaultUniverseOnly
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class AuditManagerAlpha(AuditManager):
  """Enroll resources, audit workloads and generate reports."""
